# Generated by ariadne-codegen
# Source: operations.graphql

from .base_model import BaseModel
from .fragments import PaywallFragment


class GetPaywall(BaseModel):
    paywall: "GetPaywallPaywall"


class GetPaywallPaywall(PaywallFragment):
    pass


GetPaywall.model_rebuild()
