# Generated by ariadne-codegen
# Source: operations.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .fragments import PromotionalEntitlementFragment


class GrantPromotionalEntitlementsGroup(BaseModel):
    grant_promotional_entitlements_group: List[
        "GrantPromotionalEntitlementsGroupGrantPromotionalEntitlementsGroup"
    ] = Field(alias="grantPromotionalEntitlementsGroup")


class GrantPromotionalEntitlementsGroupGrantPromotionalEntitlementsGroup(
    PromotionalEntitlementFragment
):
    pass


GrantPromotionalEntitlementsGroup.model_rebuild()
