# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import AutoRechargeSettingsFragment


class GetAutomaticRechargeConfiguration(BaseModel):
    get_auto_recharge_settings: "GetAutomaticRechargeConfigurationGetAutoRechargeSettings" = Field(
        alias="getAutoRechargeSettings"
    )


class GetAutomaticRechargeConfigurationGetAutoRechargeSettings(
    AutoRechargeSettingsFragment
):
    pass


GetAutomaticRechargeConfiguration.model_rebuild()
